@@ -80,32 +80,31 @@ src_mag_lock_xy_scale ()
 	    lock  = !lock;
 	    if (lock)
 	    {
-		gint default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
-		gint zoom_factory;
-		gint zoom_factorx;
+		gdouble default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
+		gdouble zoom_factory;
+		gdouble zoom_factorx;
 		if (!srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_Y, 
-						   CFGT_INT, 
+						   CFGT_FLOAT, 
 						   &zoom_factory, 
 						   (gpointer)&default_val,
 						   MAGNIFIER_CONFIG_PATH)
 		    ) return FALSE;
 		if (!srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_X, 
-						   CFGT_INT, 
+						   CFGT_FLOAT, 
 						   &zoom_factorx, 
 						   (gpointer)&default_val,
 						   MAGNIFIER_CONFIG_PATH)
 		    ) return FALSE;
 		
-		zoom_factorx = 
-		    zoom_factory = (zoom_factory + zoom_factorx) >> 1;
+		zoom_factorx =  zoom_factory = (zoom_factory + zoom_factorx) / 2;
 
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		    ) return FALSE;
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		    ) return FALSE;
@@ -131,13 +130,13 @@ src_mag_increase_y_scale ()
 	}
 	else
 	{
-	    gint default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
-	    gint zoom_factory;
+	    gdouble default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
+	    gdouble zoom_factory;
 	    gboolean zoom_factor_lock;
 	    gboolean zoom_factor_lock_def = DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;
 
 	    if (!srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_Y, 
-					       CFGT_INT, 
+					       CFGT_FLOAT, 
 					       &zoom_factory, 
 					       (gpointer)&default_val,
 					       MAGNIFIER_CONFIG_PATH)
@@ -154,7 +153,7 @@ src_mag_increase_y_scale ()
 	    if (!zoom_factor_lock)
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
@@ -162,12 +161,12 @@ src_mag_increase_y_scale ()
 	    else
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
@@ -189,13 +188,13 @@ src_mag_decrease_y_scale ()
 	}
 	else
 	{
-	    gint default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
-	    gint zoom_factory;
+	    gdouble default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
+	    gdouble zoom_factory;
 	    gboolean zoom_factor_lock;
 	    gboolean zoom_factor_lock_def = DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;
 
 	    if (!srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_Y, 
-					       CFGT_INT, 
+					       CFGT_FLOAT, 
 					       &zoom_factory, 
 					       (gpointer)&default_val,
 					       MAGNIFIER_CONFIG_PATH)
@@ -212,7 +211,7 @@ src_mag_decrease_y_scale ()
 	    if (!zoom_factor_lock)
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
@@ -220,12 +219,12 @@ src_mag_decrease_y_scale ()
 	    else
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factory,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
@@ -248,13 +247,13 @@ src_mag_increase_x_scale ()
 	}
 	else
 	{
-	    gint default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
-	    gint zoom_factorx;
+	    gdouble default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
+	    gdouble zoom_factorx;
 	    gboolean zoom_factor_lock;
 	    gboolean zoom_factor_lock_def = DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;
 
 	    if (!srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_X, 
-					       CFGT_INT, 
+					       CFGT_FLOAT, 
 					       &zoom_factorx, 
 					       (gpointer)&default_val,
 					       MAGNIFIER_CONFIG_PATH)
@@ -271,7 +270,7 @@ src_mag_increase_x_scale ()
 	    if (!zoom_factor_lock)
 	    {
 	        if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factorx,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
@@ -279,12 +278,12 @@ src_mag_increase_x_scale ()
     	    else
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factorx,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factorx,
 				      MAGNIFIER_CONFIG_PATH)
 	    	   ) return FALSE;
@@ -306,13 +305,13 @@ src_mag_decrease_x_scale ()
 	}
         else
 	{	
-            gint default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
-	    gint zoom_factorx;
+            gdouble default_val = DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
+	    gdouble zoom_factorx;
 	    gboolean zoom_factor_lock;
 	    gboolean zoom_factor_lock_def = DEFAULT_MAGNIFIER_ZOOM_FACTOR_LOCK;
 
 	    if (!srconf_get_data_with_default (MAGNIFIER_ZOOM_FACTOR_X, 
-					       CFGT_INT, 
+					       CFGT_FLOAT, 
 					       &zoom_factorx, 
 					       (gpointer)&default_val,
 					       MAGNIFIER_CONFIG_PATH)
@@ -329,7 +328,7 @@ src_mag_decrease_x_scale ()
 	    if (!zoom_factor_lock)
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factorx,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
@@ -337,12 +336,12 @@ src_mag_decrease_x_scale ()
 	    else
 	    {
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_Y,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factorx,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
 		if (!srconf_set_data (MAGNIFIER_ZOOM_FACTOR_X,
-				      CFGT_INT, 
+				      CFGT_FLOAT, 
 				      &zoom_factorx,
 				      MAGNIFIER_CONFIG_PATH)
 		   ) return FALSE;
