@@ -1061,7 +1061,8 @@ src_presentation_get_info_from_sro (SRObject *obj,
 		    last_offset = last_offset2;
 		if (abs (crt_offset - last_offset) == 1)
 		    type = SR_TEXT_BOUNDARY_CHAR;
-		else if (sro_text_is_same_line (obj, last_offset, SR_INDEX_CONTAINER))
+		else if (sro_text_is_same_line (obj, last_offset, SR_INDEX_CONTAINER) ||
+		         sro_is_word_navigation (obj, crt_offset, last_offset, SR_INDEX_CONTAINER))
 		    type = SR_TEXT_BOUNDARY_WORD;
 		else
 		    type = SR_TEXT_BOUNDARY_LINE;
@@ -1116,7 +1117,10 @@ src_presentation_get_info_from_sro (SRObject *obj,
 		rv = FALSE;
 		if (sro_value_get_crt_val (obj, &val, SR_INDEX_CONTAINER))
 		{
-		    *((gchar **)info) = g_strdup_printf ("%.0f", val);
+		    if (val == (int)val)
+			*((gchar **)info) = g_strdup_printf ("%.0f", val);
+		    else	
+			*((gchar **)info) = g_strdup_printf ("%.2f", val);
 		    rv = TRUE;
 		}
 	    }
