@@ -1127,6 +1127,13 @@ src_speech_shutup ()
 	g_slist_free (tmp);
     }
 #endif
+    if (last_out)
+    {
+        src_speech_idle = TRUE;
+        srcs_out_terminate (last_out);
+	last_out = NULL;
+    }
+
     src_speech_send ("<SRSOUT><SHUTUP/></SRSOUT>");
 }
 
@@ -1226,9 +1233,6 @@ src_speech_send_chunk (gchar *chunk,
     if (last_out && srcs_out_can_shutup_out (last_out, out))
     {
 	src_speech_shutup ();
-	src_speech_idle = TRUE;
-	srcs_out_terminate (last_out);
-	last_out = NULL;
     }
 
 #ifdef SRS_NO_MARKERS_SUPPORTED
@@ -1506,6 +1510,8 @@ src_speech_init ()
     sru_assert (!src_speech_initialized);
     
     src_speech_idle = TRUE;
+    srcs_outs = NULL;
+    last_out = NULL;
     src_voice_params = g_ptr_array_new ();
     
     src_voices = src_speech_src_voices_new ();
@@ -1573,6 +1579,7 @@ src_speech_terminate ()
 {
     sru_assert (src_speech_initialized);
 
+    src_speech_shutup ();
 #ifdef SRS_NO_MARKERS_SUPPORTED
     sru_assert (src_speech_unspoken == NULL);
 #endif
