@@ -193,6 +193,7 @@ static gboolean			srl_idle_installed	= FALSE;
 static GQueue			*srl_event_queue	= NULL;
 static AccessibleEventListener 	*srl_event_listeners[G_N_ELEMENTS (srl_events_type_name)];
 static Accessible		*srl_last_focus		= NULL;
+static Accessible		*srl_last_focus2	= NULL;
 static Accessible		*srl_watched_acc	= NULL;
 static Accessible 		*srl_last_table 	= NULL;
 static Accessible 		*srl_last_context 	= NULL;
@@ -1691,7 +1692,7 @@ srl_event_is_reported (SRLEvent *event)
     if (srle_has_type (event, SRL_EVENT_FOCUS) &&
         srle_acc_has_role (event, SPI_ROLE_PAGE_TAB))
     {
-	if (srl_last_focus == event->acc_ev->source)
+	if (srl_last_focus2 == event->acc_ev->source)
 	    rv = FALSE;
 	else
 	    rv = TRUE;    
@@ -1716,6 +1717,17 @@ srl_set_last_focus (Accessible *acc)
     return TRUE;
 }
 
+static gboolean
+srl_set_last_focus2 (Accessible *acc)
+{
+    if (srl_last_focus2)
+	Accessible_unref (srl_last_focus2);
+    srl_last_focus2 = acc;
+    if (srl_last_focus2)
+	Accessible_ref (srl_last_focus2);
+    return TRUE;
+}
+
 static gboolean
 srl_is_label_for (Accessible *label, Accessible *acc)
 {
@@ -1868,7 +1880,6 @@ srl_process_event (SRLEvent *event)
     srl_timing_process_start ((gpointer) event->acc_ev);
     srle_set_acc (event);
     srle_change_type (event);
-    process = srl_event_is_reported (event);
 
     if (srle_has_type (event, SRL_EVENT_FOCUS))
 	srl_check_context_changed (event);
@@ -1882,6 +1893,14 @@ srl_process_event (SRLEvent *event)
 /* FIXME: 
     if (srle_has_type (event, SRL_EVENT_WINDOW_DEACTIVATE))
 	report no focus if no other event */
+    process = srl_event_is_reported (event);	
+    
+    if (srle_has_type (event, SRL_EVENT_FOCUS) ||
+	srle_has_type (event, SRL_EVENT_FOCUS2))
+	    srl_set_last_focus2 ((Accessible*)srle_get_acc (event));
+    else if (srle_has_type (event, SRL_EVENT_FOCUS1))
+	srl_set_last_focus2 (NULL);
+	
     if (process)
 	srl_report_event (event);
 
@@ -1951,6 +1970,7 @@ srl_init ()
     for (i = 0 ; i < SRL_EVENT_PRIORITY_LAST; i++)
 	srl_last_events[i] = NULL;
     srl_last_focus	= NULL;
+    srl_last_focus2    	= NULL;
     srl_last_edit	= NULL;
     srl_idle_need	= FALSE;
     srl_idle_installed	= FALSE;
@@ -2014,6 +2034,8 @@ srl_terminate ()
 	    srle_free (srl_last_events[i]);
     if (srl_last_focus)
 	Accessible_unref (srl_last_focus);
+    if (srl_last_focus2)
+	Accessible_unref (srl_last_focus2);	
     if (srl_last_edit)
         Accessible_unref (srl_last_edit);
     if (srl_watched_acc)
